Module endpoints_api

Module endpoints_api 

Enums

CreateEndpointError
struct for typed errors of method create_endpoint
DeleteEndpointError
struct for typed errors of method delete_endpoint
GetDefaultEndpointError
struct for typed errors of method get_default_endpoint
GetEndpointError
struct for typed errors of method get_endpoint
ListEndpointsError
struct for typed errors of method list_endpoints
RestartEndpointError
struct for typed errors of method restart_endpoint

Functions

create_endpoint
Create an endpoint associated with your user account.
delete_endpoint
Delete a v1 endpoint, releasing its resources. This operation is not reversible. Forwarded to Compute v1.
get_default_endpoint
If no endpoint is set as the default, return "not found."
get_endpoint
list_endpoints
List all endpoints, optionally filtering by attribute.
restart_endpoint
Restart an entire endpoint or a single component within an endpoint.