pub async fn get_default_endpoint(
configuration: &Configuration,
quantum_processor_id: &str,
) -> Result<Endpoint, Error<GetDefaultEndpointError>>Expand description
If no endpoint is set as the default, return "not found."
pub async fn get_default_endpoint(
configuration: &Configuration,
quantum_processor_id: &str,
) -> Result<Endpoint, Error<GetDefaultEndpointError>>If no endpoint is set as the default, return "not found."