Module billing_price_recurrence

Module billing_price_recurrence 

Structs

BillingPriceRecurrence
BillingPriceRecurrence: How to invoice for the usage of a product that has a recurring (subscription) price.

Enums

AggregateUsage
How to determine the aggregate usage over the interval when usageType=metered. Using sum is recommended.
Interval
The frequency at which recurring usage should be billed. Using month is recommended.
UsageType
Use metered to calculate a dynamic quantity based on reported usage records (recommended). Use licensed when you provide a fixed quantity, e.g. a TV subscription.