Module billing_price_scheme

Module billing_price_scheme 

Enums

BillingPriceScheme
BillingPriceScheme: Use per_unit to charge a linear rate per quantity (recommended). Use tiered to charge a dynamic rate based on quantity as defined in the tiers of a BillingPice. Use per_unit to charge a linear rate per quantity (recommended). Use tiered to charge a dynamic rate based on quantity as defined in the tiers of a BillingPice.