Module billing_price_tier

Module billing_price_tier 

Structs

BillingPriceTier
BillingPriceTier: Use flatAmount to charge a fixed amount for the quantity relevant to the tier. Use unitAmount to charge a linear rate for the quantity relevant to the tier. Only one field between flatAmount, flatAmountDecimal, unitAmount, or unitAmountDecimal should be set.