pub struct BillingPriceTier {
pub flat_amount: Option<i64>,
pub flat_amount_decimal: Option<f64>,
pub unit_amount: Option<i64>,
pub unit_amount_decimal: Option<f64>,
pub up_to: i64,
}Expand description
BillingPriceTier: Use flatAmount to charge a fixed amount for the quantity relevant to the tier. Use unitAmount to charge a linear rate for the quantity relevant to the tier. Only one field between flatAmount, flatAmountDecimal, unitAmount, or unitAmountDecimal should be set.
Fields
flat_amount: Option<i64>flat_amount_decimal: Option<f64>unit_amount: Option<i64>unit_amount_decimal: Option<f64>up_to: i64The upper bound of product quantity relevant to this tier. The highest tier should be open ended, represented by an upTo value of -1.
Implementations
Sourceimpl BillingPriceTier
impl BillingPriceTier
Sourcepub fn new(up_to: i64) -> BillingPriceTier
pub fn new(up_to: i64) -> BillingPriceTier
Use flatAmount to charge a fixed amount for the quantity relevant to the tier. Use unitAmount to charge a linear rate for the quantity relevant to the tier. Only one field between flatAmount, flatAmountDecimal, unitAmount, or unitAmountDecimal should be set.