Module code

Module code 

Enums

Code
Code: API error codes to indicate what kind of error occurred beyond what an HTTP status can convey. API error codes to indicate what kind of error occurred beyond what an HTTP status can convey.