Family: Family identifier. Value ‘None’ implies the architecture has no specific layout topology. Value ‘Full’ implies that each node is connected to every other (a fully-connected architecture) For other values based on deployed architecture layouts (e.g. Aspen and Ankaa), refer to the architecture classes themselves for more details.
Family identifier. Value ‘None’ implies the architecture has no specific layout topology. Value ‘Full’ implies that each node is connected to every other (a fully-connected architecture) For other values based on deployed architecture layouts (e.g. Aspen and Ankaa), refer to the architecture classes themselves for more details.