BillingPrice: A configuration for calculating the cost of BillingProduct usage based on quantity, and when that cost should be added as an invoice item.
Use one_time to invoice immediately based on a single usage report, e.g. purchasing a QPU reservation. Use recurring to aggregate usage reports over an interval and then invoice once based on BillingPriceRecurrence, e.g. on-demand QPU usage.